using System;
using System.DirectoryServices;

namespace InfiniTec.ActiveDirectory
{

	/// <summary>
	/// Encapsulates an Active Directory search.
	/// </summary>
	public class ADSearch
	{
		string _Name;
		DirectorySearcher _Search;
		SearchResultCollection _SearchResult;

		/// <summary>
		/// Returns the <see cref="System.DirectoryServices.DirectorySearcher"/> for this search.
		/// </summary>
		public DirectorySearcher Searcher 
		{
			get 
			{
				return _Search;
			}
		}

		/// <summary>
		/// Creates a new ADSearch object.
		/// </summary>
		/// <param name="name">The friendly name of the search</param>
		/// <param name="search">The DirectorySearcher used for this search</param>
		internal ADSearch(string name, DirectorySearcher search) 
		{
			_Name = name;
			_Search = search;
			_SearchResult = null;
		}

		/// <summary>
		/// Returns the friendly name of the search
		/// </summary>
		public string Name  
		{
			get 
			{
				return _Name;
			}
		}

		/// <summary>
		/// Returns a <see cref="System.DirectoryServices.SearchResultCollection"/> containing the
		/// result from the search.
		/// </summary>
		public SearchResultCollection SearchResult 
		{
			get 
			{
				if (_SearchResult == null) _SearchResult = _Search.FindAll();
				return _SearchResult;
			}
		}

		/// <summary>
		/// Returns the name of the list.
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			return _Name;
		}

	}
}
